---
title: 'grim_gausbin_dist'
tags:
  - Gaussian Distribution
  - Binomial Distribution
  
authors:
  - name: Luís Fernando Lopes Grim
    orcid: 0000-0002-1221-4095
    affiliation: "1, 2"

affiliations:
 - name: School of Technology, University of Campinas (FT/UNICAMP)
   index: 1
 - name: Federal Institute of Education Science and Technology of Sao Paulo (IFSP)
   index: 2
date: June 19 2020

---

# Summary

This package can be used to extract parameters from Gaussian and Binomial Distributions

# References

AWS Machine Learning Foundational Course at Udacity